Some variable names still come from the paper corresponding to the crate dcf.
Macros
Structs
Cw. Correclation word.- Point function. Despite the name, it only ships an element of the domain and an element of the range. The actual meaning of the 2 elements is determined by the context.
k.
Traits
- Group (mathematics) that can be converted from a byte array